import 'package:parodia_admin/core/dto/address.dto.dart';
import 'package:parodia_admin/core/dto/base.dto.dart';
import 'package:parodia_admin/core/dto/photo.dto.dart';
import 'package:parodia_admin/core/dto/product_price.dto.dart';
import 'package:parodia_admin/core/dto/role.dto.dart';

class StoreDTO extends BaseDTO {
  bool? highlighted;
  List<Users>? users;
  PaymentMethod? paymentMethod;
  List<ShipmentMethods>? shipmentMethods;
  Info? info;
  Module? module;
  String? permission;
  Setting? setting;
  String? type;

  StoreDTO(
      {super.id,
      super.createdAt,
      super.updatedAt,
      super.isActive,
      super.isDeleted,
      this.highlighted,
      this.users,
      this.paymentMethod,
      this.shipmentMethods,
      this.info,
      this.module,
      this.permission,
      this.setting,
      this.type});

  StoreDTO.fromJson(Map<String, dynamic> json) : super.fromJson(json) {
    highlighted = json['highlighted'];
    if (json['users'] != null) {
      users = <Users>[];
      json['users'].forEach((v) {
        users!.add(Users.fromJson(v));
      });
    }
    paymentMethod = json['paymentMethod'] != null
        ? PaymentMethod.fromJson(json['paymentMethod'])
        : null;
    if (json['shipmentMethods'] != null) {
      shipmentMethods = <ShipmentMethods>[];
      json['shipmentMethods'].forEach((v) {
        shipmentMethods!.add(ShipmentMethods.fromJson(v));
      });
    }
    info = json['info'] != null ? Info.fromJson(json['info']) : null;
    module = json['module'] != null ? Module.fromJson(json['module']) : null;
    permission = json['permission'];
    setting =
        json['setting'] != null ? Setting.fromJson(json['setting']) : null;
    type = json['type'];
  }

  @override
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = super.toJson();
    data['highlighted'] = highlighted;
    if (users != null) {
      data['users'] = users!.map((v) => v.toJson()).toList();
    }
    if (paymentMethod != null) {
      data['paymentMethod'] = paymentMethod!.toJson();
    }
    if (shipmentMethods != null) {
      data['shipmentMethods'] =
          shipmentMethods!.map((v) => v.toJson()).toList();
    }
    if (info != null) {
      data['info'] = info!.toJson();
    }
    if (module != null) {
      data['module'] = module!.toJson();
    }
    data['permission'] = permission;
    if (setting != null) {
      data['setting'] = setting!.toJson();
    }
    data['type'] = type;
    return data;
  }
}

class Users {
  String? id;
  String? createdAt;
  String? email;
  String? passwordChangedAt;
  bool? isGuest;
  bool? isTest;
  String? type;
  Detail? detail;
  List<RoleDTO>? roles;

  Users(
      {this.id,
      this.createdAt,
      this.email,
      this.passwordChangedAt,
      this.isGuest,
      this.isTest,
      this.type,
      this.detail,
      this.roles});

  Users.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    email = json['email'];
    passwordChangedAt = json['passwordChangedAt'];
    isGuest = json['isGuest'];
    isTest = json['isTest'];
    type = json['type'];
    detail = json['detail'] != null ? Detail.fromJson(json['detail']) : null;
    if (json['roles'] != null) {
      roles = <RoleDTO>[];
      json['roles'].forEach((v) {
        roles!.add(RoleDTO.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['email'] = email;
    data['passwordChangedAt'] = passwordChangedAt;
    data['isGuest'] = isGuest;
    data['isTest'] = isTest;
    data['type'] = type;
    if (detail != null) {
      data['detail'] = detail!.toJson();
    }
    if (roles != null) {
      data['roles'] = roles!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Detail {
  String? id;
  String? createdAt;
  String? name;
  String? surname;
  bool? isVerified;
  String? phoneNumber;
  String? socialSecurityNo;
  String? birthday;
  String? gender;
  String? companyName;
  String? taxOffice;
  String? taxNumber;
  String? fullName;

  Detail(
      {this.id,
      this.createdAt,
      this.name,
      this.surname,
      this.isVerified,
      this.phoneNumber,
      this.socialSecurityNo,
      this.birthday,
      this.gender,
      this.companyName,
      this.taxOffice,
      this.taxNumber,
      this.fullName});

  Detail.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    name = json['name'];
    surname = json['surname'];
    isVerified = json['isVerified'];
    phoneNumber = json['phoneNumber'];
    socialSecurityNo = json['socialSecurityNo'];
    birthday = json['birthday'];
    gender = json['gender'];
    companyName = json['companyName'];
    taxOffice = json['taxOffice'];
    taxNumber = json['taxNumber'];
    fullName = json['fullName'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['name'] = name;
    data['surname'] = surname;
    data['isVerified'] = isVerified;
    data['phoneNumber'] = phoneNumber;
    data['socialSecurityNo'] = socialSecurityNo;
    data['birthday'] = birthday;
    data['gender'] = gender;
    data['companyName'] = companyName;
    data['taxOffice'] = taxOffice;
    data['taxNumber'] = taxNumber;
    data['fullName'] = fullName;
    return data;
  }
}

class PaymentMethod {
  String? id;
  String? createdAt;
  String? creditCard;
  bool? cash;
  bool? cashOnDelivery;
  bool? eft;
  bool? paypal;
  bool? stripe;
  bool? bkmExpress;

  PaymentMethod(
      {this.id,
      this.createdAt,
      this.creditCard,
      this.cash,
      this.cashOnDelivery,
      this.eft,
      this.paypal,
      this.stripe,
      this.bkmExpress});

  PaymentMethod.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    creditCard = json['creditCard'];
    cash = json['cash'];
    cashOnDelivery = json['cashOnDelivery'];
    eft = json['eft'];
    paypal = json['paypal'];
    stripe = json['stripe'];
    bkmExpress = json['bkmExpress'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['creditCard'] = creditCard;
    data['cash'] = cash;
    data['cashOnDelivery'] = cashOnDelivery;
    data['eft'] = eft;
    data['paypal'] = paypal;
    data['stripe'] = stripe;
    data['bkmExpress'] = bkmExpress;
    return data;
  }
}

class ShipmentMethods {
  String? id;
  String? createdAt;
  String? name;
  String? logoURL;
  String? type;
  String? calculationType;
  int? shipmentEstimatedDay;
  bool? showShipmentEstimatedDay;
  int? freeShipmentCargoLimit;
  bool? cashOnDelivery;
  List<ProductPriceDTO>? prices;

  ShipmentMethods(
      {this.id,
      this.createdAt,
      this.name,
      this.logoURL,
      this.type,
      this.calculationType,
      this.shipmentEstimatedDay,
      this.showShipmentEstimatedDay,
      this.freeShipmentCargoLimit,
      this.cashOnDelivery,
      this.prices});

  ShipmentMethods.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    name = json['name'];
    logoURL = json['logoURL'];
    type = json['type'];
    calculationType = json['calculationType'];
    shipmentEstimatedDay = json['shipmentEstimatedDay'];
    showShipmentEstimatedDay = json['showShipmentEstimatedDay'];
    freeShipmentCargoLimit = json['freeShipmentCargoLimit'];
    cashOnDelivery = json['cashOnDelivery'];
    if (json['prices'] != null) {
      prices = <ProductPriceDTO>[];
      json['prices'].forEach((v) {
        prices!.add(ProductPriceDTO.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['name'] = name;
    data['logoURL'] = logoURL;
    data['type'] = type;
    data['calculationType'] = calculationType;
    data['shipmentEstimatedDay'] = shipmentEstimatedDay;
    data['showShipmentEstimatedDay'] = showShipmentEstimatedDay;
    data['freeShipmentCargoLimit'] = freeShipmentCargoLimit;
    data['cashOnDelivery'] = cashOnDelivery;
    if (prices != null) {
      data['prices'] = prices!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Info {
  String? id;
  String? createdAt;
  String? name;
  String? officialTitle;
  String? domain;
  String? slug;
  AddressDTO? address;
  Contact? contact;
  Tax? tax;
  Social? social;
  PhotoDTO? logoPhoto;
  PhotoDTO? bannerPhoto;

  Info(
      {this.id,
      this.createdAt,
      this.name,
      this.officialTitle,
      this.domain,
      this.slug,
      this.address,
      this.contact,
      this.tax,
      this.social,
      this.logoPhoto,
      this.bannerPhoto});

  Info.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    name = json['name'];
    officialTitle = json['officialTitle'];
    domain = json['domain'];
    slug = json['slug'];
    address =
        json['address'] != null ? AddressDTO.fromJson(json['address']) : null;
    contact =
        json['contact'] != null ? Contact.fromJson(json['contact']) : null;
    tax = json['tax'] != null ? Tax.fromJson(json['tax']) : null;
    social = json['social'] != null ? Social.fromJson(json['social']) : null;
    logoPhoto =
        json['logoPhoto'] != null ? PhotoDTO.fromJson(json['logoPhoto']) : null;
    bannerPhoto = json['bannerPhoto'] != null
        ? PhotoDTO.fromJson(json['bannerPhoto'])
        : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['name'] = name;
    data['officialTitle'] = officialTitle;
    data['domain'] = domain;
    data['slug'] = slug;
    if (address != null) {
      data['address'] = address!.toJson();
    }
    if (contact != null) {
      data['contact'] = contact!.toJson();
    }
    if (tax != null) {
      data['tax'] = tax!.toJson();
    }
    if (social != null) {
      data['social'] = social!.toJson();
    }
    data['logoPhoto'] = logoPhoto;
    data['bannerPhoto'] = bannerPhoto;
    return data;
  }
}

class Contact {
  String? id;
  String? createdAt;
  String? name;
  String? surname;
  String? phoneNumber;

  Contact({this.id, this.createdAt, this.name, this.surname, this.phoneNumber});

  Contact.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    name = json['name'];
    surname = json['surname'];
    phoneNumber = json['phoneNumber'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['name'] = name;
    data['surname'] = surname;
    data['phoneNumber'] = phoneNumber;
    return data;
  }
}

class Tax {
  String? id;
  String? createdAt;
  String? office;
  String? number;

  Tax({this.id, this.createdAt, this.office, this.number});

  Tax.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    office = json['office'];
    number = json['number'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['office'] = office;
    data['number'] = number;
    return data;
  }
}

class Social {
  String? id;
  String? createdAt;
  String? facebook;
  String? twitter;
  String? instagram;
  String? youtube;
  String? tiktok;
  String? linkedin;
  String? udemy;

  Social(
      {this.id,
      this.createdAt,
      this.facebook,
      this.twitter,
      this.instagram,
      this.youtube,
      this.tiktok,
      this.linkedin,
      this.udemy});

  Social.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    facebook = json['facebook'];
    twitter = json['twitter'];
    instagram = json['instagram'];
    youtube = json['youtube'];
    tiktok = json['tiktok'];
    linkedin = json['linkedin'];
    udemy = json['udemy'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['facebook'] = facebook;
    data['twitter'] = twitter;
    data['instagram'] = instagram;
    data['youtube'] = youtube;
    data['tiktok'] = tiktok;
    data['linkedin'] = linkedin;
    data['udemy'] = udemy;
    return data;
  }
}

class Module {
  String? id;
  String? createdAt;
  Campaign? campaign;
  Customer? customer;
  Integration? integration;
  Campaign? order;
  Product? product;
  Stock? stock;
  Campaign? subStore;

  Module(
      {this.id,
      this.createdAt,
      this.campaign,
      this.customer,
      this.integration,
      this.order,
      this.product,
      this.stock,
      this.subStore});

  Module.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    campaign =
        json['campaign'] != null ? Campaign.fromJson(json['campaign']) : null;
    customer =
        json['customer'] != null ? Customer.fromJson(json['customer']) : null;
    integration = json['integration'] != null
        ? Integration.fromJson(json['integration'])
        : null;
    order = json['order'] != null ? Campaign.fromJson(json['order']) : null;
    product =
        json['product'] != null ? Product.fromJson(json['product']) : null;
    stock = json['stock'] != null ? Stock.fromJson(json['stock']) : null;
    subStore =
        json['subStore'] != null ? Campaign.fromJson(json['subStore']) : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    if (campaign != null) {
      data['campaign'] = campaign!.toJson();
    }
    if (customer != null) {
      data['customer'] = customer!.toJson();
    }
    if (integration != null) {
      data['integration'] = integration!.toJson();
    }
    if (order != null) {
      data['order'] = order!.toJson();
    }
    if (product != null) {
      data['product'] = product!.toJson();
    }
    if (stock != null) {
      data['stock'] = stock!.toJson();
    }
    if (subStore != null) {
      data['subStore'] = subStore!.toJson();
    }
    return data;
  }
}

class Campaign {
  String? id;
  String? createdAt;

  Campaign({this.id, this.createdAt});

  Campaign.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    return data;
  }
}

class Customer {
  String? id;
  String? createdAt;
  bool? customerPriceGroup;

  Customer({this.id, this.createdAt, this.customerPriceGroup});

  Customer.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    customerPriceGroup = json['customerPriceGroup'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['customerPriceGroup'] = customerPriceGroup;
    return data;
  }
}

class Integration {
  String? id;
  String? createdAt;
  bool? email;
  bool? sms;
  Invoicing? invoicing;
  Marketplace? marketplace;

  Integration(
      {this.id,
      this.createdAt,
      this.email,
      this.sms,
      this.invoicing,
      this.marketplace});

  Integration.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    email = json['email'];
    sms = json['sms'];
    invoicing = json['invoicing'] != null
        ? Invoicing.fromJson(json['invoicing'])
        : null;
    marketplace = json['marketplace'] != null
        ? Marketplace.fromJson(json['marketplace'])
        : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['email'] = email;
    data['sms'] = sms;
    if (invoicing != null) {
      data['invoicing'] = invoicing!.toJson();
    }
    if (marketplace != null) {
      data['marketplace'] = marketplace!.toJson();
    }
    return data;
  }
}

class Invoicing {
  String? id;
  String? createdAt;
  bool? parasut;

  Invoicing({this.id, this.createdAt, this.parasut});

  Invoicing.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    parasut = json['parasut'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['parasut'] = parasut;
    return data;
  }
}

class Marketplace {
  String? id;
  String? createdAt;
  bool? trendyol;
  bool? hepsiburada;

  Marketplace({this.id, this.createdAt, this.trendyol, this.hepsiburada});

  Marketplace.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    trendyol = json['trendyol'];
    hepsiburada = json['hepsiburada'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['trendyol'] = trendyol;
    data['hepsiburada'] = hepsiburada;
    return data;
  }
}

class Product {
  String? id;
  String? createdAt;
  bool? multipleVariant;
  bool? multiplePrice;
  bool? priceGroup;
  bool? sideProduct;

  Product(
      {this.id,
      this.createdAt,
      this.multipleVariant,
      this.multiplePrice,
      this.priceGroup,
      this.sideProduct});

  Product.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    multipleVariant = json['multipleVariant'];
    multiplePrice = json['multiplePrice'];
    priceGroup = json['priceGroup'];
    sideProduct = json['sideProduct'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['multipleVariant'] = multipleVariant;
    data['multiplePrice'] = multiplePrice;
    data['priceGroup'] = priceGroup;
    data['sideProduct'] = sideProduct;
    return data;
  }
}

class Stock {
  String? id;
  String? createdAt;
  bool? sharedStock;
  bool? warehouse;
  bool? transfer;

  Stock(
      {this.id,
      this.createdAt,
      this.sharedStock,
      this.warehouse,
      this.transfer});

  Stock.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    sharedStock = json['sharedStock'];
    warehouse = json['warehouse'];
    transfer = json['transfer'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['sharedStock'] = sharedStock;
    data['warehouse'] = warehouse;
    data['transfer'] = transfer;
    return data;
  }
}

class Setting {
  String? id;
  String? createdAt;
  Campaign? campaign;
  Customer? customer;
  Email? email;
  Campaign? order;
  Product? product;
  Sms? sms;
  Currency? currency;
  bool? analytic;

  Setting(
      {this.id,
      this.createdAt,
      this.campaign,
      this.customer,
      this.email,
      this.order,
      this.product,
      this.sms,
      this.currency,
      this.analytic});

  Setting.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    campaign =
        json['campaign'] != null ? Campaign.fromJson(json['campaign']) : null;
    customer =
        json['customer'] != null ? Customer.fromJson(json['customer']) : null;
    email = json['email'] != null ? Email.fromJson(json['email']) : null;
    order = json['order'] != null ? Campaign.fromJson(json['order']) : null;
    product =
        json['product'] != null ? Product.fromJson(json['product']) : null;
    sms = json['sms'] != null ? Sms.fromJson(json['sms']) : null;
    currency =
        json['currency'] != null ? Currency.fromJson(json['currency']) : null;
    analytic = json['analytic'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    if (campaign != null) {
      data['campaign'] = campaign!.toJson();
    }
    if (customer != null) {
      data['customer'] = customer!.toJson();
    }
    if (email != null) {
      data['email'] = email!.toJson();
    }
    if (order != null) {
      data['order'] = order!.toJson();
    }
    if (product != null) {
      data['product'] = product!.toJson();
    }
    if (sms != null) {
      data['sms'] = sms!.toJson();
    }
    if (currency != null) {
      data['currency'] = currency!.toJson();
    }
    data['analytic'] = analytic;
    return data;
  }
}

class Email {
  String? id;
  String? createdAt;
  String? sMTPHost;
  String? sMTPPort;
  String? sMTPSecure;
  String? sMTPTLS;
  String? sMTPEmail;
  String? sMTPPassword;
  bool? newCampaign;
  bool? newOrder;
  bool? changeOrderStatus;

  Email(
      {this.id,
      this.createdAt,
      this.sMTPHost,
      this.sMTPPort,
      this.sMTPSecure,
      this.sMTPTLS,
      this.sMTPEmail,
      this.sMTPPassword,
      this.newCampaign,
      this.newOrder,
      this.changeOrderStatus});

  Email.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    sMTPHost = json['SMTPHost'];
    sMTPPort = json['SMTPPort'];
    sMTPSecure = json['SMTPSecure'];
    sMTPTLS = json['SMTPTLS'];
    sMTPEmail = json['SMTPEmail'];
    sMTPPassword = json['SMTPPassword'];
    newCampaign = json['newCampaign'];
    newOrder = json['newOrder'];
    changeOrderStatus = json['changeOrderStatus'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['SMTPHost'] = sMTPHost;
    data['SMTPPort'] = sMTPPort;
    data['SMTPSecure'] = sMTPSecure;
    data['SMTPTLS'] = sMTPTLS;
    data['SMTPEmail'] = sMTPEmail;
    data['SMTPPassword'] = sMTPPassword;
    data['newCampaign'] = newCampaign;
    data['newOrder'] = newOrder;
    data['changeOrderStatus'] = changeOrderStatus;
    return data;
  }
}

class Order {
  String? id;
  String? createdAt;
  String? invoicePrefix;
  String? invoiceStartNumber;
  bool? guestOrder;
  bool? canCreateOrder;
  int? minimumCartAmount;

  Order(
      {this.id,
      this.createdAt,
      this.invoicePrefix,
      this.invoiceStartNumber,
      this.guestOrder,
      this.canCreateOrder,
      this.minimumCartAmount});

  Order.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    invoicePrefix = json['invoicePrefix'];
    invoiceStartNumber = json['invoiceStartNumber'];
    guestOrder = json['guestOrder'];
    canCreateOrder = json['canCreateOrder'];
    minimumCartAmount = json['minimumCartAmount'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['invoicePrefix'] = invoicePrefix;
    data['invoiceStartNumber'] = invoiceStartNumber;
    data['guestOrder'] = guestOrder;
    data['canCreateOrder'] = canCreateOrder;
    data['minimumCartAmount'] = minimumCartAmount;
    return data;
  }
}

class Sms {
  String? id;
  String? createdAt;
  bool? newCampaign;
  bool? newOrder;
  bool? changeOrderStatus;

  Sms(
      {this.id,
      this.createdAt,
      this.newCampaign,
      this.newOrder,
      this.changeOrderStatus});

  Sms.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    newCampaign = json['newCampaign'];
    newOrder = json['newOrder'];
    changeOrderStatus = json['changeOrderStatus'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['newCampaign'] = newCampaign;
    data['newOrder'] = newOrder;
    data['changeOrderStatus'] = changeOrderStatus;
    return data;
  }
}

class Currency {
  String? id;
  String? createdAt;
  String? baseCurrency;
  List<Rates>? rates;

  Currency({this.id, this.createdAt, this.baseCurrency, this.rates});

  Currency.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    baseCurrency = json['baseCurrency'];
    if (json['rates'] != null) {
      rates = <Rates>[];
      json['rates'].forEach((v) {
        rates!.add(Rates.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['baseCurrency'] = baseCurrency;
    if (rates != null) {
      data['rates'] = rates!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Rates {
  String? id;
  String? createdAt;
  bool? isFixed;
  String? currency;
  double? rate;

  Rates({this.id, this.createdAt, this.isFixed, this.currency, this.rate});

  Rates.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    isFixed = json['isFixed'];
    currency = json['currency'];
    rate = json['rate'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['isFixed'] = isFixed;
    data['currency'] = currency;
    data['rate'] = rate;
    return data;
  }
}
