import 'package:parodia_admin/core/dto/base.dto.dart';

class StoreSettingDTO extends BaseDTO {
  Campaign? campaign;
  Currency? currency;
  Customer? customer;
  Email? email;
  Order? order;
  Product? product;
  Sms? sms;
  String? analytic;

  StoreSettingDTO(
      {super.id,
      super.createdAt,
      super.updatedAt,
      super.isActive,
      super.isDeleted,
      this.campaign,
      this.currency,
      this.customer,
      this.email,
      this.order,
      this.product,
      this.sms,
      this.analytic});

  StoreSettingDTO.fromJson(Map<String, dynamic> json) : super.fromJson(json) {
    campaign =
        json['campaign'] != null ? Campaign.fromJson(json['campaign']) : null;
    currency =
        json['currency'] != null ? Currency.fromJson(json['currency']) : null;
    customer =
        json['customer'] != null ? Customer.fromJson(json['customer']) : null;
    email = json['email'] != null ? Email.fromJson(json['email']) : null;
    order = json['order'] != null ? Order.fromJson(json['order']) : null;
    product =
        json['product'] != null ? Product.fromJson(json['product']) : null;
    sms = json['sms'] != null ? Sms.fromJson(json['sms']) : null;
    analytic = json['analytic'];
  }

  @override
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = super.toJson();
    if (campaign != null) {
      data['campaign'] = campaign!.toJson();
    }
    if (currency != null) {
      data['currency'] = currency!.toJson();
    }
    if (customer != null) {
      data['customer'] = customer!.toJson();
    }
    if (email != null) {
      data['email'] = email!.toJson();
    }
    if (order != null) {
      data['order'] = order!.toJson();
    }
    if (product != null) {
      data['product'] = product!.toJson();
    }
    if (sms != null) {
      data['sms'] = sms!.toJson();
    }
    data['analytic'] = analytic;
    return data;
  }
}

class Campaign {
  String? id;
  String? createdAt;
  bool? customersCanUseMultipleCampaign;

  Campaign({this.id, this.createdAt, this.customersCanUseMultipleCampaign});

  Campaign.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    customersCanUseMultipleCampaign = json['customersCanUseMultipleCampaign'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['customersCanUseMultipleCampaign'] = customersCanUseMultipleCampaign;
    return data;
  }
}

class Currency {
  String? id;
  String? createdAt;
  String? baseCurrency;
  List<Rates>? rates;

  Currency({this.id, this.createdAt, this.baseCurrency, this.rates});

  Currency.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    baseCurrency = json['baseCurrency'];
    if (json['rates'] != null) {
      rates = <Rates>[];
      json['rates'].forEach((v) {
        rates!.add(Rates.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['baseCurrency'] = baseCurrency;
    if (rates != null) {
      data['rates'] = rates!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Rates {
  String? id;
  String? createdAt;
  bool? isFixed;
  String? currency;
  double? rate;

  Rates({this.id, this.createdAt, this.isFixed, this.currency, this.rate});

  Rates.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    isFixed = json['isFixed'];
    currency = json['currency'];
    rate = json['rate'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['isFixed'] = isFixed;
    data['currency'] = currency;
    data['rate'] = rate;
    return data;
  }
}

class Customer {
  String? id;
  String? createdAt;
  bool? verifyUsers;

  Customer({this.id, this.createdAt, this.verifyUsers});

  Customer.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    verifyUsers = json['verifyUsers'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['verifyUsers'] = verifyUsers;
    return data;
  }
}

class Email {
  String? id;
  String? createdAt;
  String? sMTPHost;
  String? sMTPPort;
  String? sMTPSecure;
  String? sMTPTLS;
  String? sMTPEmail;
  String? sMTPPassword;
  bool? newCampaign;
  bool? newOrder;
  bool? changeOrderStatus;

  Email(
      {this.id,
      this.createdAt,
      this.sMTPHost,
      this.sMTPPort,
      this.sMTPSecure,
      this.sMTPTLS,
      this.sMTPEmail,
      this.sMTPPassword,
      this.newCampaign,
      this.newOrder,
      this.changeOrderStatus});

  Email.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    sMTPHost = json['SMTPHost'];
    sMTPPort = json['SMTPPort'];
    sMTPSecure = json['SMTPSecure'];
    sMTPTLS = json['SMTPTLS'];
    sMTPEmail = json['SMTPEmail'];
    sMTPPassword = json['SMTPPassword'];
    newCampaign = json['newCampaign'];
    newOrder = json['newOrder'];
    changeOrderStatus = json['changeOrderStatus'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['SMTPHost'] = sMTPHost;
    data['SMTPPort'] = sMTPPort;
    data['SMTPSecure'] = sMTPSecure;
    data['SMTPTLS'] = sMTPTLS;
    data['SMTPEmail'] = sMTPEmail;
    data['SMTPPassword'] = sMTPPassword;
    data['newCampaign'] = newCampaign;
    data['newOrder'] = newOrder;
    data['changeOrderStatus'] = changeOrderStatus;
    return data;
  }
}

class Order {
  String? id;
  String? createdAt;
  String? invoicePrefix;
  String? invoiceStartNumber;
  bool? guestOrder;
  bool? canCreateOrder;
  int? minimumCartAmount;

  Order(
      {this.id,
      this.createdAt,
      this.invoicePrefix,
      this.invoiceStartNumber,
      this.guestOrder,
      this.canCreateOrder,
      this.minimumCartAmount});

  Order.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    invoicePrefix = json['invoicePrefix'];
    invoiceStartNumber = json['invoiceStartNumber'];
    guestOrder = json['guestOrder'];
    canCreateOrder = json['canCreateOrder'];
    minimumCartAmount = json['minimumCartAmount'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['invoicePrefix'] = invoicePrefix;
    data['invoiceStartNumber'] = invoiceStartNumber;
    data['guestOrder'] = guestOrder;
    data['canCreateOrder'] = canCreateOrder;
    data['minimumCartAmount'] = minimumCartAmount;
    return data;
  }
}

class Product {
  String? id;
  String? createdAt;
  bool? verifyRatings;
  bool? showNoStocks;
  String? showPrice;

  Product(
      {this.id,
      this.createdAt,
      this.verifyRatings,
      this.showNoStocks,
      this.showPrice});

  Product.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    verifyRatings = json['verifyRatings'];
    showNoStocks = json['showNoStocks'];
    showPrice = json['showPrice'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['verifyRatings'] = verifyRatings;
    data['showNoStocks'] = showNoStocks;
    data['showPrice'] = showPrice;
    return data;
  }
}

class Sms {
  String? id;
  String? createdAt;
  bool? newCampaign;
  bool? newOrder;
  bool? changeOrderStatus;

  Sms(
      {this.id,
      this.createdAt,
      this.newCampaign,
      this.newOrder,
      this.changeOrderStatus});

  Sms.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    newCampaign = json['newCampaign'];
    newOrder = json['newOrder'];
    changeOrderStatus = json['changeOrderStatus'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['newCampaign'] = newCampaign;
    data['newOrder'] = newOrder;
    data['changeOrderStatus'] = changeOrderStatus;
    return data;
  }
}
