import 'package:parodia_admin/core/dto/base.dto.dart';
import 'package:parodia_admin/core/dto/store.dto.dart';

class TicketDTO extends BaseDTO {
  String? title;
  String? status;
  int? code;
  String? delegatedTo;
  List<Items>? items;
  List<User>? assignedUsers;
  User? createdUser;
  Category? category;
  StoreDTO? store;

  TicketDTO(
      {super.id,
      super.createdAt,
      super.updatedAt,
      super.isActive,
      super.isDeleted,
      this.title,
      this.status,
      this.code,
      this.delegatedTo,
      this.items,
      this.assignedUsers,
      this.createdUser,
      this.category,
      this.store});

  TicketDTO.fromJson(Map<String, dynamic> json) : super.fromJson(json) {
    title = json['title'];
    status = json['status'];
    code = json['code'];
    delegatedTo = json['delegatedTo'];
    if (json['items'] != null) {
      items = <Items>[];
      json['items'].forEach((v) {
        items!.add(Items.fromJson(v));
      });
    }
    if (json['assignedUsers'] != null) {
      assignedUsers = <User>[];
      json['assignedUsers'].forEach((v) {
        assignedUsers!.add(User.fromJson(v));
      });
    }
    createdUser =
        json['createdUser'] != null ? User.fromJson(json['createdUser']) : null;
    category =
        json['category'] != null ? Category.fromJson(json['category']) : null;
    store = json['store'] != null ? StoreDTO.fromJson(json['store']) : null;
  }

  @override
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = super.toJson();
    data['title'] = title;
    data['status'] = status;
    data['code'] = code;
    data['delegatedTo'] = delegatedTo;
    if (items != null) {
      data['items'] = items!.map((v) => v.toJson()).toList();
    }
    if (assignedUsers != null) {
      data['assignedUsers'] = assignedUsers!.map((v) => v.toJson()).toList();
    }
    if (createdUser != null) {
      data['createdUser'] = createdUser!.toJson();
    }
    if (category != null) {
      data['category'] = category!.toJson();
    }
    if (store != null) {
      data['store'] = store!.toJson();
    }
    return data;
  }
}

class Items {
  String? id;
  String? createdAt;
  String? message;
  User? user;
  List<void>? files;

  Items({this.id, this.createdAt, this.message, this.user, this.files});

  Items.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    message = json['message'];
    user = json['user'] != null ? User.fromJson(json['user']) : null;
    // if (json['files'] != null) {
    //   files = <Null>[];
    //   json['files'].forEach((v) {
    //     files!.add(void.fromJson(v));
    //   });
    // }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['message'] = message;
    if (user != null) {
      data['user'] = user!.toJson();
    }
    // if (files != null) {
    //   data['files'] = files!.map((v) => v.toJson()).toList();
    // }
    return data;
  }
}

class Detail {
  String? id;
  String? createdAt;
  String? name;
  String? surname;
  bool? isVerified;
  String? phoneNumber;
  String? socialSecurityNo;
  String? birthday;
  String? gender;
  String? companyName;
  String? taxOffice;
  String? taxNumber;
  String? fullName;

  Detail(
      {this.id,
      this.createdAt,
      this.name,
      this.surname,
      this.isVerified,
      this.phoneNumber,
      this.socialSecurityNo,
      this.birthday,
      this.gender,
      this.companyName,
      this.taxOffice,
      this.taxNumber,
      this.fullName});

  Detail.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    name = json['name'];
    surname = json['surname'];
    isVerified = json['isVerified'];
    phoneNumber = json['phoneNumber'];
    socialSecurityNo = json['socialSecurityNo'];
    birthday = json['birthday'];
    gender = json['gender'];
    companyName = json['companyName'];
    taxOffice = json['taxOffice'];
    taxNumber = json['taxNumber'];
    fullName = json['fullName'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['name'] = name;
    data['surname'] = surname;
    data['isVerified'] = isVerified;
    data['phoneNumber'] = phoneNumber;
    data['socialSecurityNo'] = socialSecurityNo;
    data['birthday'] = birthday;
    data['gender'] = gender;
    data['companyName'] = companyName;
    data['taxOffice'] = taxOffice;
    data['taxNumber'] = taxNumber;
    data['fullName'] = fullName;
    return data;
  }
}

class User {
  String? id;
  String? createdAt;
  String? email;
  String? passwordChangedAt;
  bool? isGuest;
  bool? isTest;
  String? type;
  Detail? detail;

  User(
      {this.id,
      this.createdAt,
      this.email,
      this.passwordChangedAt,
      this.isGuest,
      this.isTest,
      this.type,
      this.detail});

  User.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    email = json['email'];
    passwordChangedAt = json['passwordChangedAt'];
    isGuest = json['isGuest'];
    isTest = json['isTest'];
    type = json['type'];
    detail = json['detail'] != null ? Detail.fromJson(json['detail']) : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['email'] = email;
    data['passwordChangedAt'] = passwordChangedAt;
    data['isGuest'] = isGuest;
    data['isTest'] = isTest;
    data['type'] = type;
    if (detail != null) {
      data['detail'] = detail!.toJson();
    }
    return data;
  }
}

class Category {
  String? id;
  String? createdAt;
  String? name;

  Category({this.id, this.createdAt, this.name});

  Category.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    name = json['name'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['name'] = name;
    return data;
  }
}
