/// A model for validation errors.
///
/// This class represents a validation error, with a message and a property.
/// It provides methods to convert the validation error to and from a JSON object.
class ValidationErrorModel {
  /// The message of the validation error.
  String? message;

  /// The property that the validation error is associated with.
  dynamic property;

  /// Creates a new instance of [ValidationErrorModel].
  ///
  /// The [message] and [property] parameters can be used to specify the message and property for the validation error.
  ValidationErrorModel({
    required this.message,
    required this.property,
  });

  /// Creates a new instance of [ValidationErrorModel] from a JSON object.
  ///
  /// This method extracts the [message] and [property] properties from the [json] parameter and uses them to initialize a new instance of [ValidationErrorModel].
  ValidationErrorModel.fromJson(Map<String, dynamic> json) {
    message = json['message'];
    property = json['property'];
  }

  /// Converts the [ValidationErrorModel] to a JSON object.
  ///
  /// This method can be used when making HTTP requests to convert the validation error to a format that can be sent in the request.
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['message'] = message;
    data['property'] = property;
    return data;
  }
}
