import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/provider/providers.dart';
import 'package:provider/single_child_widget.dart';

/// A class for initializing and managing the Parodia service.
///
/// This class provides methods to initialize the service, set the authentication token and currency, and get the providers.
/// It uses the Singleton pattern to ensure that only one instance of the class is created.
class Parodia {
  /// Whether the Parodia service has been initialized.
  bool _isInitialized = false;
  bool get isInitialized => _isInitialized;

  /// The HTTP service used by Parodia.
  ParodiaHTTP? _http;
  ParodiaHTTP? get http => _http;

  /// The base URL for the Parodia service.
  String? _baseUrl;
  String? get baseUrl => _baseUrl;

  /// The store key for the Parodia service.
  String? _storeKey;

  /// The authentication token for the Parodia service.
  String? _authToken;
  String? get authToken => _authToken;
  set setAuthToken(String? token) {
    if (_isInitialized == false) {
      throw Exception("Parodia should be initialized.");
    }
    _authToken = token;
    _http!.setAuthToken = token;
  }

  /// The currency for the Parodia service.
  String? _currency;
  String? get currency => _currency;
  set setCurrency(String? currency) {
    if (_isInitialized == false) {
      throw Exception("Parodia should be initialized.");
    }
    _currency = currency;
    _http!.setCurrency = currency;
  }

  /// The providers for the Parodia service.
  List<SingleChildWidget> get providers {
    if (!Providers.isInitialized) {
      throw Exception("Providers is not initialized.");
    }
    return Providers.providers;
  }

  /// The private constructor for the Parodia class.
  Parodia._privateConstructor();

  /// The single instance of the Parodia class.
  static final Parodia _instance = Parodia._privateConstructor();
  static Parodia get instance => _instance;

  /// Initializes the Parodia service.
  ///
  /// This method sets the base URL, store key, and authentication token for the service.
  /// It also initializes the HTTP service and the providers.
  init({
    required String baseUrl,
    required String storeKey,
    String? authToken,
  }) {
    if (_isInitialized == true) {
      return;
    }
    _isInitialized = true;
    _baseUrl = baseUrl;
    _storeKey = storeKey;
    _authToken = authToken;

    _http = ParodiaHTTP(
      baseUrl: _baseUrl!,
      storeKey: _storeKey!,
      authToken: _authToken,
    );

    Providers.init(_http!);
  }
}
