// GET
// /api/v1/dashboard/dashboard/blogs/{id}

// PUT
// /api/v1/dashboard/dashboard/blogs/{id}

// DELETE
// /api/v1/dashboard/dashboard/blogs/{id}

// GET
// /api/v1/dashboard/dashboard/blogs

// POST
// /api/v1/dashboard/dashboard/blogs

// POST
// /api/v1/dashboard/dashboard/blogs/{id}/recover

import 'package:parodia_admin/core/dto/blog.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class BlogRepository {
  ParodiaHTTP? _http;

  BlogRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<BlogDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/blogs',
      param: id,
    );

    return ResponseItemDTO<BlogDTO>(
      response: response,
      fromJson: BlogDTO.fromJson,
    );
  }

  Future<ResponseListDTO<BlogDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/blogs',
      query: query,
    );

    return ResponseListDTO<BlogDTO>(
      response: response,
      fromJson: BlogDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({BlogBody? blog}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/blogs',
      data: blog,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, BlogBody? blog}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/blogs',
      param: id,
      data: blog,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/blogs',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/blogs/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
