// POST
// /api/v1/dashboard/dashboard/brands/slugify

// GET
// /api/v1/dashboard/dashboard/brands/{id}

// PUT
// /api/v1/dashboard/dashboard/brands/{id}

// DELETE
// /api/v1/dashboard/dashboard/brands/{id}

// GET
// /api/v1/dashboard/dashboard/brands

// POST
// /api/v1/dashboard/dashboard/brands

// POST
// /api/v1/dashboard/dashboard/brands/{id}/recover

import 'package:parodia_admin/core/dto/brand.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class BrandRepository {
  ParodiaHTTP? _http;

  BrandRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO> create({BrandBody? brand}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/brands',
      data: brand,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/brands',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseListDTO<BrandDTO>> getAll({BrandQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/brands',
      query: query,
    );

    return ResponseListDTO<BrandDTO>(
      response: response,
      fromJson: BrandDTO.fromJson,
    );
  }

  Future<ResponseItemDTO<BrandDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/brands',
      param: id,
    );

    return ResponseItemDTO<BrandDTO>(
      response: response,
      fromJson: BrandDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/brands/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/brands/slugify',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, BrandBody? brand}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/brands',
      param: id,
      data: brand,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
