// GET
// /api/v1/dashboard/dashboard/catalogs/{id}

// PUT
// /api/v1/dashboard/dashboard/catalogs/{id}

// DELETE
// /api/v1/dashboard/dashboard/catalogs/{id}

// GET
// /api/v1/dashboard/dashboard/catalogs

// POST
// /api/v1/dashboard/dashboard/catalogs

// POST
// /api/v1/dashboard/dashboard/catalogs/{id}/recover

import 'package:parodia_admin/core/dto/catalog.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class CatalogRepository {
  ParodiaHTTP? _http;

  CatalogRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<CatalogDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/catalogs',
      param: id,
    );

    return ResponseItemDTO<CatalogDTO>(
      response: response,
      fromJson: CatalogDTO.fromJson,
    );
  }

  Future<ResponseListDTO<CatalogDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/catalogs',
      query: query,
    );

    return ResponseListDTO<CatalogDTO>(
      response: response,
      fromJson: CatalogDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({CatalogBody? catalog}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/catalogs',
      data: catalog,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, CatalogBody? catalog}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/catalogs',
      param: id,
      data: catalog,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/catalogs',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/catalogs/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
