import 'package:parodia_admin/core/dto/notification.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';

class NotificationRepository {
  ParodiaHTTP? _http;

  NotificationRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<NotificationDTO>> getById(String id) async {
    var response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/notifications/$id',
    );

    return ResponseItemDTO<NotificationDTO>(
      response: response,
      fromJson: NotificationDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({NotificationBody? body}) async {
    var response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/notifications',
      data: body,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, NotificationBody? body}) async {
    var response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/notifications/$id',
      data: body,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete(String id) async {
    var response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/notifications/$id',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover(String id) async {
    var response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/notifications/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseListDTO<NotificationDTO>> getAll() async {
    var response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/notifications',
    );

    return ResponseListDTO<NotificationDTO>(
      response: response,
      fromJson: NotificationDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> sendToAll({NotificationBody? body}) async {
    var response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/notifications/to-all',
      data: body,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
