// GET
// /api/v1/dashboard/dashboard/orders/{id}

// PUT
// /api/v1/dashboard/dashboard/orders/{id}

// GET
// /api/v1/dashboard/dashboard/orders

import 'package:parodia_admin/core/dto/order.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class OrderRepository {
  ParodiaHTTP? _http;

  OrderRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<OrderDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/orders',
      param: id,
    );

    return ResponseItemDTO<OrderDTO>(
      response: response,
      fromJson: OrderDTO.fromJson,
    );
  }

  Future<ResponseListDTO<OrderDTO>> getAll({OrderQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/orders',
      query: query,
    );

    return ResponseListDTO<OrderDTO>(
      response: response,
      fromJson: OrderDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> update({String? id, OrderPutBody? order}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/orders',
      param: id,
      data: order,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> assign({String? id, OrderAssignBody? body}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/orders/$id/assign',
      data: body,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
