// GET
// /api/v1/dashboard/stocks/dashboard/stocks/outs/{id}

// PUT
// /api/v1/dashboard/stocks/dashboard/stocks/outs/{id}

// DELETE
// /api/v1/dashboard/stocks/dashboard/stocks/outs/{id}

// GET
// /api/v1/dashboard/stocks/dashboard/stocks/outs

// POST
// /api/v1/dashboard/stocks/dashboard/stocks/outs

// POST
// /api/v1/dashboard/stocks/dashboard/stocks/outs/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/stock.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class OutStockRepository {
  ParodiaHTTP? _http;

  OutStockRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<StockDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/stocks/outs',
      param: id,
    );

    return ResponseItemDTO<StockDTO>(
      response: response,
      fromJson: StockDTO.fromJson,
    );
  }

  Future<ResponseListDTO<StockDTO>> getAll({StockQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/stocks/outs',
      query: query,
    );

    return ResponseListDTO<StockDTO>(
      response: response,
      fromJson: StockDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({OutStockBody? outStock}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/stocks/outs',
      data: outStock,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, OutStockBody? outStock}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/stocks/outs',
      param: id,
      data: outStock,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/stocks/outs',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/stocks/outs/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
