// GET
// /api/v1/dashboard/dashboard/photos/folders//folders/{id}

// PUT
// /api/v1/dashboard/dashboard/photos/folders//folders/{id}

// DELETE
// /api/v1/dashboard/dashboard/photos/folders//folders/{id}

// GET
// /api/v1/dashboard/dashboard/photos/folders//folders/folders

// POST
// /api/v1/dashboard/dashboard/photos/folders//folders/folders

// POST
// /api/v1/dashboard/dashboard/photos/folders//folders/folders/{id}/recover

import 'package:parodia_admin/core/dto/photo_folder.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class PhotoFolderRepository {
  ParodiaHTTP? _http;

  PhotoFolderRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<PhotoFolderDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/photos/folders/',
      param: id,
    );

    return ResponseItemDTO<PhotoFolderDTO>(
      response: response,
      fromJson: PhotoFolderDTO.fromJson,
    );
  }

  Future<ResponseListDTO<PhotoFolderDTO>> getAll({
    StoreQuery? query,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/photos/folders/',
    );

    return ResponseListDTO<PhotoFolderDTO>(
      response: response,
      fromJson: PhotoFolderDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({PhotoFolderBody? photoFolder}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/photos/folders/',
      data: photoFolder,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, PhotoFolderBody? photoFolder}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/photos/folders/',
      param: id,
      data: photoFolder,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/photos/folders/',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/photos/folders//$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
