// GET
// /api/v1/dashboard/dashboard/products/ratings

// PUT
// /api/v1/dashboard/dashboard/products/ratings/{id}

// DELETE
// /api/v1/dashboard/dashboard/products/ratings/{id}

// POST
// /api/v1/dashboard/dashboard/products/ratings/{id}/recover

import 'package:parodia_admin/core/dto/rating.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class ProductRatingRepository {
  ParodiaHTTP? _http;

  ProductRatingRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseListDTO<RatingDTO>> getAll({
    ProductPriceAndRatingQuery? query,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/products/ratings',
      query: query,
    );

    return ResponseListDTO<RatingDTO>(
      response: response,
      fromJson: RatingDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, ProductRatingPutBody? rating}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/products/ratings',
      param: id,
      data: rating,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/products/ratings',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/products/ratings/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
