// GET
// /api/v1/dashboard/dashboard/promo_codes/{id}

// PUT
// /api/v1/dashboard/dashboard/promo_codes/{id}

// DELETE
// /api/v1/dashboard/dashboard/promo_codes/{id}

// GET
// /api/v1/dashboard/dashboard/promo_codes

// POST
// /api/v1/dashboard/dashboard/promo_codes

// POST
// /api/v1/dashboard/dashboard/promo_codes/{id}/recover

import 'package:parodia_admin/core/dto/promo_code.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class PromoCodeRepository {
  ParodiaHTTP? _http;

  PromoCodeRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<PromoCodeDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/promo_codes',
      param: id,
    );

    return ResponseItemDTO<PromoCodeDTO>(
      response: response,
      fromJson: PromoCodeDTO.fromJson,
    );
  }

  Future<ResponseListDTO<PromoCodeDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/promo_codes',
      query: query,
    );

    return ResponseListDTO<PromoCodeDTO>(
      response: response,
      fromJson: PromoCodeDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({PromoCodeBody? promoCode}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/promo_codes',
      data: promoCode,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, PromoCodeBody? promoCode}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/promo_codes',
      param: id,
      data: promoCode,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/promo_codes',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/promo_codes/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
