// GET
// /api/v1/dashboard/dashboard/roles/{id}

// PUT
// /api/v1/dashboard/dashboard/roles/{id}

// DELETE
// /api/v1/dashboard/dashboard/roles/{id}

// GET
// /api/v1/dashboard/dashboard/roles

// POST
// /api/v1/dashboard/dashboard/roles

// POST
// /api/v1/dashboard/dashboard/roles/{id}/recover
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/role.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class RoleRepository {
  ParodiaHTTP? _http;

  RoleRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<RoleDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/roles',
      param: id,
    );

    return ResponseItemDTO<RoleDTO>(
      response: response,
      fromJson: RoleDTO.fromJson,
    );
  }

  Future<ResponseListDTO<RoleDTO>> getAll({VariantQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/roles',
      query: query,
    );

    return ResponseListDTO<RoleDTO>(
      response: response,
      fromJson: RoleDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({RoleBody? role}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/roles',
      data: role,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, RoleBody? role}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/roles',
      param: id,
      data: role,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/roles',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/roles/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
