// GET
// /api/v1/dashboard/dashboard/suggestions

// PUT
// /api/v1/dashboard/dashboard/suggestions/{id}/solve

// DELETE
// /api/v1/dashboard/dashboard/suggestions/{id}

// POST
// /api/v1/dashboard/dashboard/suggestions/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/suggestion.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class SuggestionsRepository {
  ParodiaHTTP? _http;

  SuggestionsRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseListDTO<SuggestionDTO>> getAll({SuggestionQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/suggestions',
      query: query,
    );

    return ResponseListDTO<SuggestionDTO>(
      response: response,
      fromJson: SuggestionDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> solve({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/suggestions',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/suggestions',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/suggestions',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
    );
  }
}
