// GET
// /api/v1/dashboard/dashboard/suppliers/{id}

// PUT
// /api/v1/dashboard/dashboard/suppliers/{id}

// DELETE
// /api/v1/dashboard/dashboard/suppliers/{id}

// GET
// /api/v1/dashboard/dashboard/suppliers

// POST
// /api/v1/dashboard/dashboard/suppliers

// POST
// /api/v1/dashboard/dashboard/suppliers/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/supplier.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class SupplierRepository {
  ParodiaHTTP? _http;

  SupplierRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<SupplierDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/suppliers',
      param: id,
    );

    return ResponseItemDTO<SupplierDTO>(
      response: response,
      fromJson: SupplierDTO.fromJson,
    );
  }

  Future<ResponseListDTO<SupplierDTO>> getAll({
    StoreQuery? query,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/suppliers',
      query: query,
    );

    return ResponseListDTO<SupplierDTO>(
      response: response,
      fromJson: SupplierDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({SupplierBody? supplier}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/suppliers',
      data: supplier,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, SupplierBody? supplier}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/suppliers',
      param: id,
      data: supplier,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/suppliers',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/suppliers/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
