// GET
// /api/v1/dashboard/dashboard/themes/{id}

// PUT
// /api/v1/dashboard/dashboard/themes/{id}

// DELETE
// /api/v1/dashboard/dashboard/themes/{id}

// GET
// /api/v1/dashboard/dashboard/themes

// POST
// /api/v1/dashboard/dashboard/themes

// POST
// /api/v1/dashboard/dashboard/themes/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/theme.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class ThemeRepository {
  ParodiaHTTP? _http;

  ThemeRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ThemeDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/themes',
      param: id,
    );

    return ResponseItemDTO<ThemeDTO>(
      response: response,
      fromJson: ThemeDTO.fromJson,
    );
  }

  Future<ResponseListDTO<ThemeDTO>> getAll({
     StoreQuery? query,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/themes',
    );

    return ResponseListDTO<ThemeDTO>(
      response: response,
      fromJson: ThemeDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({ThemeBody? theme}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/themes',
      data: theme,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, ThemeBody? theme}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/themes',
      param: id,
      data: theme,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/themes',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/themes/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
