// GET
// /api/v1/dashboard/dashboard/transfers/{id}

// PUT
// /api/v1/dashboard/dashboard/transfers/{id}

// DELETE
// /api/v1/dashboard/dashboard/transfers/{id}

// GET
// /api/v1/dashboard/dashboard/transfers

// POST
// /api/v1/dashboard/dashboard/transfers

// POST
// /api/v1/dashboard/dashboard/transfers/{id}/complete

// POST
// /api/v1/dashboard/dashboard/transfers/{id}/recover
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/transfer.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class TransferRepository {
  ParodiaHTTP? _http;

  TransferRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<TransferDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/transfers',
      param: id,
    );

    return ResponseItemDTO<TransferDTO>(
      response: response,
      fromJson: TransferDTO.fromJson,
    );
  }

  Future<ResponseListDTO<TransferDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/transfers',
      query: query,
    );

    return ResponseListDTO<TransferDTO>(
      response: response,
      fromJson: TransferDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({TransferBody? transfer}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/transfers',
      data: transfer,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, TransferBody? transfer}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/transfers',
      param: id,
      data: transfer,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> complete(
      {String? id, TransferCompleteBody? body}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/transfers/$id/complete',
      data: body,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/transfers',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/transfers/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
