// GET
// /api/v1/dashboard/dashboard/users/{id}

// PUT
// /api/v1/dashboard/dashboard/users/{id}

// DELETE
// /api/v1/dashboard/dashboard/users/{id}

// GET
// /api/v1/dashboard/dashboard/users

// POST
// /api/v1/dashboard/dashboard/users

// POST
// /api/v1/dashboard/dashboard/users/{id}/recover
import 'package:parodia_admin/core/dto/profile.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class UserRepository {
  ParodiaHTTP? _http;

  UserRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ProfileDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/users',
      param: id,
    );

    return ResponseItemDTO<ProfileDTO>(
      response: response,
      fromJson: ProfileDTO.fromJson,
    );
  }

  Future<ResponseListDTO<ProfileDTO>> getAll({StoreUserQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/users',
      query: query,
    );

    return ResponseListDTO<ProfileDTO>(
      response: response,
      fromJson: ProfileDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({UserBody? user}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/users',
      data: user,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, UserBody? user}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/users',
      param: id,
      data: user,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/users',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/users/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
