// GET
// /api/v1/dashboard/dashboard/variants/{id}

// PUT
// /api/v1/dashboard/dashboard/variants/{id}

// DELETE
// /api/v1/dashboard/dashboard/variants/{id}

// GET
// /api/v1/dashboard/dashboard/variants

// POST
// /api/v1/dashboard/dashboard/variants

// POST
// /api/v1/dashboard/dashboard/variants/multiple

// POST
// /api/v1/dashboard/dashboard/variants/{id}/recover
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/variant.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
class VariantRepository {
  ParodiaHTTP? _http;

  VariantRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<VariantDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/variants',
      param: id,
    );

    return ResponseItemDTO<VariantDTO>(
      response: response,
      fromJson: VariantDTO.fromJson,
    );
  }

  Future<ResponseListDTO<VariantDTO>> getAll({VariantQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/variants',
      query: query,
    );

    return ResponseListDTO<VariantDTO>(
      response: response,
      fromJson: VariantDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({VariantBody? variant}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/variants',
      data: variant,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> multiple({VariantMultipleBody? variant}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/variants/multiple',
      data: variant,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, VariantBody? variant}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/variants',
      param: id,
      data: variant,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/variants',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/variants/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
