// GET
// /api/v1/dashboard/dashboard/variants/groups/{id}

// PUT
// /api/v1/dashboard/dashboard/variants/groups/{id}

// DELETE
// /api/v1/dashboard/dashboard/variants/groups/{id}

// GET
// /api/v1/dashboard/dashboard/variants/groups

// POST
// /api/v1/dashboard/dashboard/variants/groups

// POST
// /api/v1/dashboard/dashboard/variants/groups/{id}/recover
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/variant_group.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class VariantGroupRepository {
  ParodiaHTTP? _http;

  VariantGroupRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<VariantGroupDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/variants/groups',
      param: id,
    );

    return ResponseItemDTO<VariantGroupDTO>(
      response: response,
      fromJson: VariantGroupDTO.fromJson,
    );
  }

  Future<ResponseListDTO<VariantGroupDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/variants/groups',
      query: query,
    );

    return ResponseListDTO<VariantGroupDTO>(
      response: response,
      fromJson: VariantGroupDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({VariantGroupBody? variantGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/variants/groups',
      data: variantGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, VariantGroupBody? variantGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/variants/groups',
      param: id,
      data: variantGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/variants/groups',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/variants/groups/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
