// GET
// /api/v1/dashboard/dashboard/vehicles/{id}

// PUT
// /api/v1/dashboard/dashboard/vehicles/{id}

// DELETE
// /api/v1/dashboard/dashboard/vehicles/{id}

// GET
// /api/v1/dashboard/dashboard/vehicles

// POST
// /api/v1/dashboard/dashboard/vehicles

// POST
// /api/v1/dashboard/dashboard/vehicles/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/vehicle.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class VehicleRepository {
  ParodiaHTTP? _http;

  VehicleRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<VehicleDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/vehicles',
      param: id,
    );

    return ResponseItemDTO<VehicleDTO>(
      response: response,
      fromJson: VehicleDTO.fromJson,
    );
  }

  Future<ResponseListDTO<VehicleDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/vehicles',
      query: query,
    );

    return ResponseListDTO<VehicleDTO>(
      response: response,
      fromJson: VehicleDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({VehicleBody? vehicle}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/vehicles',
      data: vehicle,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, VehicleBody? vehicle}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/vehicles',
      param: id,
      data: vehicle,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/vehicles',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/vehicles/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
