// GET
// /api/v1/dashboard/dashboard/warehouses/{id}

// PUT
// /api/v1/dashboard/dashboard/warehouses/{id}

// DELETE
// /api/v1/dashboard/dashboard/warehouses/{id}

// GET
// /api/v1/dashboard/dashboard/warehouses

// POST
// /api/v1/dashboard/dashboard/warehouses

// POST
// /api/v1/dashboard/dashboard/warehouses/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/warehouse.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class WarehouseRepository {
  ParodiaHTTP? _http;

  WarehouseRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<WarehouseDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/warehouses',
      param: id,
    );

    return ResponseItemDTO<WarehouseDTO>(
      response: response,
      fromJson: WarehouseDTO.fromJson,
    );
  }

  Future<ResponseListDTO<WarehouseDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/warehouses',
      query: query,
    );

    return ResponseListDTO<WarehouseDTO>(
      response: response,
      fromJson: WarehouseDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({WarehouseBody? warehouse}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/warehouses',
      data: warehouse,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, WarehouseBody? warehouse}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/warehouses',
      param: id,
      data: warehouse,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/warehouses',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/warehouses/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
