import 'package:flutter/material.dart';
import 'package:parodia_admin/core/dto/brand.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
import 'package:parodia_admin/core/repository/brand.repository.dart';

class ParodiaBrandProvider with ChangeNotifier {
  BrandRepository? _repository;

  ParodiaBrandProvider();
  ParodiaBrandProvider.init(ParodiaHTTP http) {
    _repository = BrandRepository(http);
  }

  Future<ResponseItemDTO<BrandDTO>> getById({String? id}) async {
    return await _repository!.getById(
      id: id,
    );
  }

  Future<ResponseListDTO<BrandDTO>> getAll({BrandQuery? query}) async {
    return await _repository!.getAll(
      query: query,
    );
  }

  Future<ResponseItemDTO> create({BrandBody? brand}) async {
    return await _repository!.create(
      brand: brand,
    );
  }

  Future<ResponseItemDTO> update({String? id, BrandBody? brand}) async {
    return await _repository!.update(
      id: id,
      brand: brand,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    return await _repository!.delete(
      id: id,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    return await _repository!.recover(
      id: id,
    );
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    return await _repository!.slugify(
      id: id,
    );
  }
}
