import 'package:flutter/material.dart';
import 'package:parodia_admin/core/dto/feature.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
import 'package:parodia_admin/core/repository/feature.repository.dart';

class ParodiaFeatureProvider with ChangeNotifier {
  FeatureRepository? _repository;

  ParodiaFeatureProvider();
  ParodiaFeatureProvider.init(ParodiaHTTP http) {
    _repository = FeatureRepository(http);
  }

  Future<ResponseItemDTO<FeatureDTO>> getById({String? id}) async {
    return await _repository!.getById(
      id: id,
    );
  }

  Future<ResponseListDTO<FeatureDTO>> getAll({StoreQuery? query}) async {
    return await _repository!.getAll(
      query: query,
    );
  }

  Future<ResponseItemDTO> create({FeatureBody? feature}) async {
    return await _repository!.create(
      feature: feature,
    );
  }

  Future<ResponseItemDTO> update({String? id, FeatureBody? feature}) async {
    return await _repository!.update(
      id: id,
      feature: feature,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    return await _repository!.delete(
      id: id,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    return await _repository!.recover(
      id: id,
    );
  }
}
