import 'package:flutter/material.dart';
import 'package:parodia_admin/core/dto/photo.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
import 'package:parodia_admin/core/repository/photo.repository.dart';

class ParodiaPhotoProvider with ChangeNotifier {
  PhotoRepository? _repository;

  ParodiaPhotoProvider();
  ParodiaPhotoProvider.init(ParodiaHTTP http) {
    _repository = PhotoRepository(http);
  }

  Future<ResponseItemDTO<PhotoDTO>> getById({String? id}) async {
    return await _repository!.getById(
      id: id,
    );
  }

  Future<ResponseListDTO<PhotoDTO>> getAll({PhotoQuery? query}) async {
    return await _repository!.getAll(
      query: query,
    );
  }

  Future<ResponseItemDTO> create({PhotoBody? photo}) async {
    return await _repository!.create(
      photo: photo,
    );
  }

  Future<ResponseItemDTO> multiple(
      {String? id, PhotoMultipleBody? photos}) async {
    return await _repository!.multiple(
      id: id,
      photos: photos,
    );
  }

  Future<ResponseItemDTO> update({String? id, PhotoBody? photo}) async {
    return await _repository!.update(
      id: id,
      photo: photo,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    return await _repository!.delete(
      id: id,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    return await _repository!.recover(
      id: id,
    );
  }
}
