import 'package:flutter/material.dart';
import 'package:parodia_admin/core/dto/product_price.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
import 'package:parodia_admin/core/repository/productPrice.repository.dart';

class ParodiaProductPriceProvider with ChangeNotifier {
  ProductPriceRepository? _repository;

  ParodiaProductPriceProvider();
  ParodiaProductPriceProvider.init(ParodiaHTTP http) {
    _repository = ProductPriceRepository(http);
  }

  Future<ResponseItemDTO<ProductPriceDTO>> getById({String? id}) async {
    return await _repository!.getById(
      id: id,
    );
  }

  Future<ResponseListDTO<ProductPriceDTO>> getAll({
    ProductPriceAndRatingQuery? query,
  }) async {
    return await _repository!.getAll(
      query: query,
    );
  }

  Future<ResponseItemDTO> create({PriceBody? price}) async {
    return await _repository!.create(
      price: price,
    );
  }

  Future<ResponseItemDTO> multiple(
      {String? id, PriceMultiplePutBody? productCatalogs}) async {
    return await _repository!.multiple(
      id: id,
      productCatalogs: productCatalogs,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, ProductCatalogBody? price}) async {
    return await _repository!.update(
      id: id,
      price: price,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    return await _repository!.delete(
      id: id,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    return await _repository!.recover(
      id: id,
    );
  }
}
