import 'package:flutter/material.dart';
import 'package:parodia_admin/core/dto/product.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
import 'package:parodia_admin/core/repository/products.repository.dart';

class ParodiaProductProvider with ChangeNotifier {
  ProductRepository? _repository;

  ParodiaProductProvider();
  ParodiaProductProvider.init(ParodiaHTTP http) {
    _repository = ProductRepository(http);
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    return await _repository!.slugify(
      id: id,
    );
  }

  Future<ResponseItemDTO<ProductDTO>> getById({String? id}) async {
    return await _repository!.getById(
      id: id,
    );
  }

  Future<ResponseListDTO<ProductDTO>> getAll({ProductQuery? query}) async {
    return await _repository!.getAll(
      query: query,
    );
  }

  Future<ResponseItemDTO> create({ProductBody? product}) async {
    return await _repository!.create(
      product: product,
    );
  }

  Future<ResponseItemDTO> multiple(
      {String? id, ProductMultiplePutBody? body}) async {
    return await _repository!.multiple(
      id: id,
      body: body,
    );
  }

  Future<ResponseItemDTO> multipleDelete(
      {String? id, ProductMultipleDeleteBody? body}) async {
    return await _repository!.multipleDelete(
      id: id,
      body: body,
    );
  }

  Future<ResponseItemDTO> update({String? id, ProductBody? body}) async {
    return await _repository!.update(
      id: id,
      body: body,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    return await _repository!.delete(
      id: id,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    return await _repository!.recover(
      id: id,
    );
  }
}
