import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/provider/assignedCatalog.provider.dart';
import 'package:parodia_admin/provider/auth.provider.dart';
import 'package:parodia_admin/provider/blog.provider.dart';
import 'package:parodia_admin/provider/brand.provider.dart';
import 'package:parodia_admin/provider/campaign.provider.dart';
import 'package:parodia_admin/provider/catalog.provider.dart';
import 'package:parodia_admin/provider/category.provider.dart';
import 'package:parodia_admin/provider/city.provider.dart';
import 'package:parodia_admin/provider/feature.provider.dart';
import 'package:parodia_admin/provider/global.provider.dart';
import 'package:parodia_admin/provider/inStock.provider.dart';
import 'package:parodia_admin/provider/mailTemplate.provider.dart';
import 'package:parodia_admin/provider/notification.provider.dart';
import 'package:parodia_admin/provider/order.provider.dart';
import 'package:parodia_admin/provider/orderRefund.provider.dart';
import 'package:parodia_admin/provider/outStock.provider.dart';
import 'package:parodia_admin/provider/photo.provider.dart';
import 'package:parodia_admin/provider/photoFolder.provider.dart';
import 'package:parodia_admin/provider/productCatalog.provider.dart';
import 'package:parodia_admin/provider/productPrice.provider.dart';
import 'package:parodia_admin/provider/productPriceGroup.provider.dart';
import 'package:parodia_admin/provider/productRating.provider.dart';
import 'package:parodia_admin/provider/products.provider.dart';
import 'package:parodia_admin/provider/profile.provider.dart';
import 'package:parodia_admin/provider/promoCode.provider.dart';
import 'package:parodia_admin/provider/report.provider.dart';
import 'package:parodia_admin/provider/role.provider.dart';
import 'package:parodia_admin/provider/roleGroup.provider.dart';
import 'package:parodia_admin/provider/stock.provider.dart';
import 'package:parodia_admin/provider/stockList.provider.dart';
import 'package:parodia_admin/provider/storeRating.provider.dart';
import 'package:parodia_admin/provider/storeSetting.provider.dart';
import 'package:parodia_admin/provider/storeSettingCurrency.provider.dart';
import 'package:parodia_admin/provider/storeShipmentMethod.provider.dart';
import 'package:parodia_admin/provider/storeType.provider.dart';
import 'package:parodia_admin/provider/stores.provider.dart';
import 'package:parodia_admin/provider/suggestion.provider.dart';
import 'package:parodia_admin/provider/supplier.provider.dart';
import 'package:parodia_admin/provider/tag.provider.dart';
import 'package:parodia_admin/provider/tax.provider.dart';
import 'package:parodia_admin/provider/theme.provider.dart';
import 'package:parodia_admin/provider/ticket.provider.dart';
import 'package:parodia_admin/provider/ticketCategory.provider.dart';
import 'package:parodia_admin/provider/timeline.provider.dart';
import 'package:parodia_admin/provider/transfer.provider.dart';
import 'package:parodia_admin/provider/userGroup.provider.dart';
import 'package:parodia_admin/provider/users.provider.dart';
import 'package:parodia_admin/provider/variant.provider.dart';
import 'package:parodia_admin/provider/variantGroup.provider.dart';
import 'package:parodia_admin/provider/vehicle.provider.dart';
import 'package:parodia_admin/provider/warehouse.provider.dart';
import 'package:provider/provider.dart';
import 'package:provider/single_child_widget.dart';

/// Provides a centralized way to manage all providers.
///
/// This class holds a list of all providers and initializes them with an instance of [ParodiaHTTP].
/// It ensures that the providers are only initialized once.
class Providers {
  static final List<SingleChildWidget> _providers = [];
  static List<SingleChildWidget> get providers => _providers;

  static bool _isInitialized = false;
  static bool get isInitialized => _isInitialized;

  /// Initializes all providers with an instance of [ParodiaHTTP].
  ///
  /// This method should only be called once. If the providers have already been initialized, it does nothing.
  static init(ParodiaHTTP http) {
    if (_isInitialized) {
      return;
    }

    // Add all providers to the list and initialize them with the http instance.
    // Each provider is wrapped in a ChangeNotifierProvider to enable it to notify its listeners when changes occur.
    // Replace the provider names with the actual names of your providers.
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaAssignedCatalogProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaAuthProvider.init(http),
      ),
    );
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaBrandProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaBlogProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaCampaignProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaCategoryProvider.init(http),
      ),
    );
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaCityProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaGlobalProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaFeatureProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaInStockProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaMailTemplateProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaOrderProvider.init(http),
      ),
    );
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaOrderRefundProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaOutStockProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaPhotoProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaPhotoFolderProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaProductCatalogProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaProductPriceProvider.init(http),
      ),
    );
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaProductPriceGroupProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaProductRatingProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaProductProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaProfileProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaPromoCodeProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaReportProvider.init(http),
      ),
    );
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaRoleProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaRoleGroupProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaStockProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaStockListProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaStoreRatingProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaStoreProvider.init(http),
      ),
    );
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaStoreSettingProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaStoreSettingCurrencyProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaStoreShipmentMethodProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaStoreTypeProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaSuggestionProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaSupplierProvider.init(http),
      ),
    );
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaTagProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaTaxProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaThemeProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaTicketProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaTicketCategoryProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaTimelineProvider.init(http),
      ),
    );
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaTransferProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaUserGroupProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaUserProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaVariantProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaVariantGroupProvider.init(http),
      ),
    );

    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaVehicleProvider.init(http),
      ),
    );
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaWarehouseProvider.init(http),
      ),
    );
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaNotificationProvider.init(http),
      ),
    );
    providers.add(
      ChangeNotifierProvider(
        create: (_) => ParodiaCatalogProvider.init(http),
      ),
    );
    _isInitialized = true;
  }
}
