import 'package:flutter/material.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/tag.dto.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
import 'package:parodia_admin/core/repository/tag.repository.dart';

class ParodiaTagProvider with ChangeNotifier {
  TagRepository? _repository;

  ParodiaTagProvider();
  ParodiaTagProvider.init(ParodiaHTTP http) {
    _repository = TagRepository(http);
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    return await _repository!.slugify(
      id: id,
    );
  }

  Future<ResponseItemDTO<TagDTO>> getById({String? id}) async {
    return await _repository!.getById(
      id: id,
    );
  }

  Future<ResponseListDTO<TagDTO>> getAll({
    StoreQuery? query,
  }) async {
    return await _repository!.getAll(
      query: query,
    );
  }

  Future<ResponseItemDTO> create({TagBody? tag}) async {
    return await _repository!.create(
      tag: tag,
    );
  }

  Future<ResponseItemDTO> update({String? id, TagBody? tag}) async {
    return await _repository!.update(
      id: id,
      tag: tag,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    return await _repository!.delete(
      id: id,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    return await _repository!.recover(
      id: id,
    );
  }
}
