import 'package:flutter/material.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/ticket.dto.dart';
import 'package:parodia_admin/core/dto/ticket_category.dto.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
import 'package:parodia_admin/core/repository/ticket.repository.dart';

class ParodiaTicketProvider with ChangeNotifier {
  TicketRepository? _repository;

  ParodiaTicketProvider();
  ParodiaTicketProvider.init(ParodiaHTTP http) {
    _repository = TicketRepository(http);
  }

  Future<ResponseListDTO<TicketCategoryDTO>> getCategories() async {
    return await _repository!.getCategories();
  }

  Future<ResponseItemDTO<TicketDTO>> getById({String? id}) async {
    return await _repository!.getById(
      id: id,
    );
  }

  Future<ResponseListDTO<TicketDTO>> getAll({TicketQuery? query}) async {
    return await _repository!.getAll(
      query: query,
    );
  }

  Future<ResponseItemDTO> create({ThemeBody? theme}) async {
    return await _repository!.create(
      theme: theme,
    );
  }

  Future<ResponseItemDTO> update({String? id, ThemeBody? theme}) async {
    return await _repository!.update(
      id: id,
      theme: theme,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    return await _repository!.delete(
      id: id,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    return await _repository!.recover(
      id: id,
    );
  }

  Future<ResponseItemDTO> addMessage(
      {String? id, TicketMessageBody? message}) async {
    return await _repository!.addMessage(
      id: id,
      message: message,
    );
  }

  Future<ResponseItemDTO> delegate({String? id}) async {
    return await _repository!.delegate(
      id: id,
    );
  }

  Future<ResponseItemDTO> assign(
      {String? id, TicketAssignPutBody? assign}) async {
    return await _repository!.assign(
      id: id,
      assign: assign,
    );
  }
}
