import 'package:flutter/material.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/transfer.dto.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
import 'package:parodia_admin/core/repository/transfer.repository.dart';

class ParodiaTransferProvider with ChangeNotifier {
  TransferRepository? _repository;

  ParodiaTransferProvider();
  ParodiaTransferProvider.init(ParodiaHTTP http) {
    _repository = TransferRepository(http);
  }

  Future<ResponseItemDTO<TransferDTO>> getById({String? id}) async {
    return await _repository!.getById(
      id: id,
    );
  }

  Future<ResponseListDTO<TransferDTO>> getAll({StoreQuery? query}) async {
    return await _repository!.getAll(
      query: query,
    );
  }

  Future<ResponseItemDTO> create({TransferBody? transfer}) async {
    return await _repository!.create(
      transfer: transfer,
    );
  }

  Future<ResponseItemDTO> update({String? id, TransferBody? transfer}) async {
    return await _repository!.update(
      id: id,
      transfer: transfer,
    );
  }

  Future<ResponseItemDTO> complete(
      {String? id, TransferCompleteBody? body}) async {
    return await _repository!.complete(
      id: id,
      body: body,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    return await _repository!.delete(
      id: id,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    return await _repository!.recover(
      id: id,
    );
  }
}
