import 'package:flutter/material.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/variant.dto.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
import 'package:parodia_admin/core/repository/variant.repository.dart';

class ParodiaVariantProvider with ChangeNotifier {
  VariantRepository? _repository;

  ParodiaVariantProvider();
  ParodiaVariantProvider.init(ParodiaHTTP http) {
    _repository = VariantRepository(http);
  }

  Future<ResponseItemDTO<VariantDTO>> getById({String? id}) async {
    return await _repository!.getById(
      id: id,
    );
  }

  Future<ResponseListDTO<VariantDTO>> getAll({VariantQuery? query}) async {
    return await _repository!.getAll(
      query: query,
    );
  }

  Future<ResponseItemDTO> create({VariantBody? variant}) async {
    return await _repository!.create(
      variant: variant,
    );
  }

  Future<ResponseItemDTO> multiple({VariantMultipleBody? variant}) async {
    return await _repository!.multiple(
      variant: variant,
    );
  }

  Future<ResponseItemDTO> update({String? id, VariantBody? variant}) async {
    return await _repository!.update(
      id: id,
      variant: variant,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    return await _repository!.delete(
      id: id,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    return await _repository!.recover(
      id: id,
    );
  }
}
